"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const xml_1 = __importDefault(require("./helper/xml"));
class Shape {
    constructor(relsXmlInfo, sourceArchive, sourceSlideNumber) {
        this.sourceNumber = relsXmlInfo.number;
        this.sourceRid = relsXmlInfo.rId;
        this.sourceArchive = sourceArchive;
        this.sourceSlideNumber = sourceSlideNumber;
        this.sourceSlideFile = `ppt/slides/slide${this.sourceSlideNumber}.xml`;
    }
    setTarget(targetTemplate, targetSlideNumber) {
        return __awaiter(this, void 0, void 0, function* () {
            this.targetTemplate = targetTemplate;
            this.targetArchive = yield this.targetTemplate.archive;
            this.targetSlideNumber = targetSlideNumber;
            this.targetSlideFile = `ppt/slides/slide${this.targetSlideNumber}.xml`;
            this.targetSlideRelFile = `ppt/slides/_rels/slide${this.targetSlideNumber}.xml.rels`;
        });
    }
    appendToSlideTree() {
        return __awaiter(this, void 0, void 0, function* () {
            let sourceSlideXml = yield xml_1.default.getXmlFromArchive(this.sourceArchive, this.sourceSlideFile);
            let sourceElement = yield this.getElementByRid(sourceSlideXml, this.sourceRid);
            let targetElement = sourceElement.cloneNode(true);
            let targetSlideXml = yield xml_1.default.getXmlFromArchive(this.targetArchive, this.targetSlideFile);
            targetSlideXml.getElementsByTagName('p:spTree')[0].appendChild(targetElement);
            yield xml_1.default.writeXmlToArchive(this.targetArchive, this.targetSlideFile, targetSlideXml);
        });
    }
    getElementByRid(slideXml, rId) {
        return __awaiter(this, void 0, void 0, function* () {
            let sourceChartList = slideXml.getElementsByTagName('p:spTree')[0].getElementsByTagName(this.relRootTag);
            let sourceElement = xml_1.default.findByAttributeValue(sourceChartList, this.relAttribute, rId);
            return this.relParent(sourceElement);
        });
    }
    updateElementRelId() {
        return __awaiter(this, void 0, void 0, function* () {
            let targetSlideXml = yield xml_1.default.getXmlFromArchive(this.targetArchive, this.targetSlideFile);
            let targetElement = yield this.getElementByRid(targetSlideXml, this.sourceRid);
            targetElement.getElementsByTagName(this.relRootTag)[0].setAttribute(this.relAttribute, this.createdRid);
            yield xml_1.default.writeXmlToArchive(this.targetArchive, this.targetSlideFile, targetSlideXml);
        });
    }
}
exports.default = Shape;
//# sourceMappingURL=shape.js.map